Documentation
¶
Overview ¶
Package attestation implements the Azure ARM Attestation service API version 2020-10-01.
Various APIs for managing resources in attestation service. This primarily encompasses per-tenant instance management.
Index ¶
- Constants
- func UserAgent() string
- func Version() string
- type AzureEntityResource
- type BaseClient
- type CloudError
- type CloudErrorBody
- type CreatedByType
- type JSONWebKey
- type JSONWebKeySet
- type OperationList
- type OperationsClient
- func (client OperationsClient) List(ctx context.Context) (result OperationList, err error)
- func (client OperationsClient) ListPreparer(ctx context.Context) (*http.Request, error)
- func (client OperationsClient) ListResponder(resp *http.Response) (result OperationList, err error)
- func (client OperationsClient) ListSender(req *http.Request) (*http.Response, error)
- type OperationsDefinition
- type OperationsDisplayDefinition
- type Provider
- type ProviderListResult
- type ProvidersClient
- func (client ProvidersClient) Create(ctx context.Context, resourceGroupName string, providerName string, ...) (result Provider, err error)
- func (client ProvidersClient) CreatePreparer(ctx context.Context, resourceGroupName string, providerName string, ...) (*http.Request, error)
- func (client ProvidersClient) CreateResponder(resp *http.Response) (result Provider, err error)
- func (client ProvidersClient) CreateSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) Delete(ctx context.Context, resourceGroupName string, providerName string) (result autorest.Response, err error)
- func (client ProvidersClient) DeletePreparer(ctx context.Context, resourceGroupName string, providerName string) (*http.Request, error)
- func (client ProvidersClient) DeleteResponder(resp *http.Response) (result autorest.Response, err error)
- func (client ProvidersClient) DeleteSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) Get(ctx context.Context, resourceGroupName string, providerName string) (result Provider, err error)
- func (client ProvidersClient) GetDefaultByLocation(ctx context.Context, location string) (result Provider, err error)
- func (client ProvidersClient) GetDefaultByLocationPreparer(ctx context.Context, location string) (*http.Request, error)
- func (client ProvidersClient) GetDefaultByLocationResponder(resp *http.Response) (result Provider, err error)
- func (client ProvidersClient) GetDefaultByLocationSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) GetPreparer(ctx context.Context, resourceGroupName string, providerName string) (*http.Request, error)
- func (client ProvidersClient) GetResponder(resp *http.Response) (result Provider, err error)
- func (client ProvidersClient) GetSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) List(ctx context.Context) (result ProviderListResult, err error)
- func (client ProvidersClient) ListByResourceGroup(ctx context.Context, resourceGroupName string) (result ProviderListResult, err error)
- func (client ProvidersClient) ListByResourceGroupPreparer(ctx context.Context, resourceGroupName string) (*http.Request, error)
- func (client ProvidersClient) ListByResourceGroupResponder(resp *http.Response) (result ProviderListResult, err error)
- func (client ProvidersClient) ListByResourceGroupSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) ListDefault(ctx context.Context) (result ProviderListResult, err error)
- func (client ProvidersClient) ListDefaultPreparer(ctx context.Context) (*http.Request, error)
- func (client ProvidersClient) ListDefaultResponder(resp *http.Response) (result ProviderListResult, err error)
- func (client ProvidersClient) ListDefaultSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) ListPreparer(ctx context.Context) (*http.Request, error)
- func (client ProvidersClient) ListResponder(resp *http.Response) (result ProviderListResult, err error)
- func (client ProvidersClient) ListSender(req *http.Request) (*http.Response, error)
- func (client ProvidersClient) Update(ctx context.Context, resourceGroupName string, providerName string, ...) (result Provider, err error)
- func (client ProvidersClient) UpdatePreparer(ctx context.Context, resourceGroupName string, providerName string, ...) (*http.Request, error)
- func (client ProvidersClient) UpdateResponder(resp *http.Response) (result Provider, err error)
- func (client ProvidersClient) UpdateSender(req *http.Request) (*http.Response, error)
- type ProxyResource
- type Resource
- type ServiceCreationParams
- type ServiceCreationSpecificParams
- type ServicePatchParams
- type ServiceStatus
- type StatusResult
- type SystemData
- type TrackedResource
Constants ¶
const (
// DefaultBaseURI is the default URI used for the service Attestation
DefaultBaseURI = "https://management.azure.com"
)
Variables ¶
This section is empty.
Functions ¶
func UserAgent ¶
func UserAgent() string
UserAgent returns the UserAgent string to use when sending http.Requests.
func Version ¶
func Version() string
Version returns the semantic version (see http://semver.org) of the client.
Types ¶
type AzureEntityResource ¶
type AzureEntityResource struct {
// Etag - READ-ONLY; Resource Etag.
Etag *string `json:"etag,omitempty"`
// ID - READ-ONLY; Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
ID *string `json:"id,omitempty"`
// Name - READ-ONLY; The name of the resource
Name *string `json:"name,omitempty"`
// Type - READ-ONLY; The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
AzureEntityResource the resource model definition for an Azure Resource Manager resource with an etag.
func (AzureEntityResource) MarshalJSON ¶
func (aer AzureEntityResource) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for AzureEntityResource.
type BaseClient ¶
BaseClient is the base client for Attestation.
func New ¶
func New(subscriptionID string) BaseClient
New creates an instance of the BaseClient client.
func NewWithBaseURI ¶
func NewWithBaseURI(baseURI string, subscriptionID string) BaseClient
NewWithBaseURI creates an instance of the BaseClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
type CloudError ¶
type CloudError struct {
Error *CloudErrorBody `json:"error,omitempty"`
}
CloudError an error response from Attestation.
type CloudErrorBody ¶
type CloudErrorBody struct {
// Code - An identifier for the error. Codes are invariant and are intended to be consumed programmatically.
Code *string `json:"code,omitempty"`
// Message - A message describing the error, intended to be suitable for displaying in a user interface.
Message *string `json:"message,omitempty"`
}
CloudErrorBody an error response from Attestation.
type CreatedByType ¶
type CreatedByType string
CreatedByType enumerates the values for created by type.
const ( // Application ... Application CreatedByType = "Application" // Key ... Key CreatedByType = "Key" // ManagedIdentity ... ManagedIdentity CreatedByType = "ManagedIdentity" // User ... User CreatedByType = "User" )
func PossibleCreatedByTypeValues ¶
func PossibleCreatedByTypeValues() []CreatedByType
PossibleCreatedByTypeValues returns an array of possible values for the CreatedByType const type.
type JSONWebKey ¶
type JSONWebKey struct {
// Alg - The "alg" (algorithm) parameter identifies the algorithm intended for
// use with the key. The values used should either be registered in the
// IANA "JSON Web Signature and Encryption Algorithms" registry
// established by [JWA] or be a value that contains a Collision-
// Resistant Name.
Alg *string `json:"alg,omitempty"`
// Crv - The "crv" (curve) parameter identifies the curve type
Crv *string `json:"crv,omitempty"`
// D - RSA private exponent or ECC private key
D *string `json:"d,omitempty"`
// Dp - RSA Private Key Parameter
Dp *string `json:"dp,omitempty"`
// Dq - RSA Private Key Parameter
Dq *string `json:"dq,omitempty"`
// E - RSA public exponent, in Base64
E *string `json:"e,omitempty"`
// K - Symmetric key
K *string `json:"k,omitempty"`
// Kid - The "kid" (key ID) parameter is used to match a specific key. This
// is used, for instance, to choose among a set of keys within a JWK Set
// during key rollover. The structure of the "kid" value is
// unspecified. When "kid" values are used within a JWK Set, different
// keys within the JWK Set SHOULD use distinct "kid" values. (One
// example in which different keys might use the same "kid" value is if
// they have different "kty" (key type) values but are considered to be
// equivalent alternatives by the application using them.) The "kid"
// value is a case-sensitive string.
Kid *string `json:"kid,omitempty"`
// Kty - The "kty" (key type) parameter identifies the cryptographic algorithm
// family used with the key, such as "RSA" or "EC". "kty" values should
// either be registered in the IANA "JSON Web Key Types" registry
// established by [JWA] or be a value that contains a Collision-
// Resistant Name. The "kty" value is a case-sensitive string.
Kty *string `json:"kty,omitempty"`
// N - RSA modulus, in Base64
N *string `json:"n,omitempty"`
// P - RSA secret prime
P *string `json:"p,omitempty"`
// Q - RSA secret prime, with p < q
Q *string `json:"q,omitempty"`
// Qi - RSA Private Key Parameter
Qi *string `json:"qi,omitempty"`
// Use - Use ("public key use") identifies the intended use of
// the public key. The "use" parameter is employed to indicate whether
// a public key is used for encrypting data or verifying the signature
// on data. Values are commonly "sig" (signature) or "enc" (encryption).
Use *string `json:"use,omitempty"`
// X - X coordinate for the Elliptic Curve point
X *string `json:"x,omitempty"`
// X5c - The "x5c" (X.509 certificate chain) parameter contains a chain of one
// or more PKIX certificates [RFC5280]. The certificate chain is
// represented as a JSON array of certificate value strings. Each
// string in the array is a base64-encoded (Section 4 of [RFC4648] --
// not base64url-encoded) DER [ITU.X690.1994] PKIX certificate value.
// The PKIX certificate containing the key value MUST be the first
// certificate.
X5c *[]string `json:"x5c,omitempty"`
// Y - Y coordinate for the Elliptic Curve point
Y *string `json:"y,omitempty"`
}
JSONWebKey ...
type JSONWebKeySet ¶
type JSONWebKeySet struct {
// Keys - The value of the "keys" parameter is an array of JWK values. By
// default, the order of the JWK values within the array does not imply
// an order of preference among them, although applications of JWK Sets
// can choose to assign a meaning to the order for their purposes, if
// desired.
Keys *[]JSONWebKey `json:"keys,omitempty"`
}
JSONWebKeySet ...
type OperationList ¶
type OperationList struct {
autorest.Response `json:"-"`
// SystemData - READ-ONLY; The system metadata relating to this resource
SystemData *SystemData `json:"systemData,omitempty"`
// Value - List of supported operations.
Value *[]OperationsDefinition `json:"value,omitempty"`
}
OperationList list of supported operations.
func (OperationList) MarshalJSON ¶
func (ol OperationList) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for OperationList.
type OperationsClient ¶
type OperationsClient struct {
BaseClient
}
OperationsClient is the various APIs for managing resources in attestation service. This primarily encompasses per-tenant instance management.
func NewOperationsClient ¶
func NewOperationsClient(subscriptionID string) OperationsClient
NewOperationsClient creates an instance of the OperationsClient client.
func NewOperationsClientWithBaseURI ¶
func NewOperationsClientWithBaseURI(baseURI string, subscriptionID string) OperationsClient
NewOperationsClientWithBaseURI creates an instance of the OperationsClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (OperationsClient) List ¶
func (client OperationsClient) List(ctx context.Context) (result OperationList, err error)
List lists all of the available Azure attestation operations.
func (OperationsClient) ListPreparer ¶
ListPreparer prepares the List request.
func (OperationsClient) ListResponder ¶
func (client OperationsClient) ListResponder(resp *http.Response) (result OperationList, err error)
ListResponder handles the response to the List request. The method always closes the http.Response Body.
func (OperationsClient) ListSender ¶
ListSender sends the List request. The method will close the http.Response Body if it receives an error.
type OperationsDefinition ¶
type OperationsDefinition struct {
// Name - Name of the operation.
Name *string `json:"name,omitempty"`
// Display - Display object with properties of the operation.
Display *OperationsDisplayDefinition `json:"display,omitempty"`
}
OperationsDefinition definition object with the name and properties of an operation.
type OperationsDisplayDefinition ¶
type OperationsDisplayDefinition struct {
// Provider - Resource provider of the operation.
Provider *string `json:"provider,omitempty"`
// Resource - Resource for the operation.
Resource *string `json:"resource,omitempty"`
// Operation - Short description of the operation.
Operation *string `json:"operation,omitempty"`
// Description - Description of the operation.
Description *string `json:"description,omitempty"`
}
OperationsDisplayDefinition display object with properties of the operation.
type Provider ¶
type Provider struct {
autorest.Response `json:"-"`
// SystemData - READ-ONLY; The system metadata relating to this resource
SystemData *SystemData `json:"systemData,omitempty"`
// StatusResult - Describes Attestation service status.
*StatusResult `json:"properties,omitempty"`
// Tags - Resource tags.
Tags map[string]*string `json:"tags"`
// Location - The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// ID - READ-ONLY; Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
ID *string `json:"id,omitempty"`
// Name - READ-ONLY; The name of the resource
Name *string `json:"name,omitempty"`
// Type - READ-ONLY; The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
Provider attestation service response message.
func (Provider) MarshalJSON ¶
MarshalJSON is the custom marshaler for Provider.
func (*Provider) UnmarshalJSON ¶
UnmarshalJSON is the custom unmarshaler for Provider struct.
type ProviderListResult ¶
type ProviderListResult struct {
autorest.Response `json:"-"`
// SystemData - READ-ONLY; The system metadata relating to this resource
SystemData *SystemData `json:"systemData,omitempty"`
// Value - Attestation Provider array.
Value *[]Provider `json:"value,omitempty"`
}
ProviderListResult attestation Providers List.
func (ProviderListResult) MarshalJSON ¶
func (plr ProviderListResult) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for ProviderListResult.
type ProvidersClient ¶
type ProvidersClient struct {
BaseClient
}
ProvidersClient is the various APIs for managing resources in attestation service. This primarily encompasses per-tenant instance management.
func NewProvidersClient ¶
func NewProvidersClient(subscriptionID string) ProvidersClient
NewProvidersClient creates an instance of the ProvidersClient client.
func NewProvidersClientWithBaseURI ¶
func NewProvidersClientWithBaseURI(baseURI string, subscriptionID string) ProvidersClient
NewProvidersClientWithBaseURI creates an instance of the ProvidersClient client using a custom endpoint. Use this when interacting with an Azure cloud that uses a non-standard base URI (sovereign clouds, Azure stack).
func (ProvidersClient) Create ¶
func (client ProvidersClient) Create(ctx context.Context, resourceGroupName string, providerName string, creationParams ServiceCreationParams) (result Provider, err error)
Create creates a new Attestation Provider instance. Parameters: resourceGroupName - the name of the resource group. The name is case insensitive. providerName - name of the attestation service instance. creationParams - client supplied parameters.
func (ProvidersClient) CreatePreparer ¶
func (client ProvidersClient) CreatePreparer(ctx context.Context, resourceGroupName string, providerName string, creationParams ServiceCreationParams) (*http.Request, error)
CreatePreparer prepares the Create request.
func (ProvidersClient) CreateResponder ¶
func (client ProvidersClient) CreateResponder(resp *http.Response) (result Provider, err error)
CreateResponder handles the response to the Create request. The method always closes the http.Response Body.
func (ProvidersClient) CreateSender ¶
CreateSender sends the Create request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) Delete ¶
func (client ProvidersClient) Delete(ctx context.Context, resourceGroupName string, providerName string) (result autorest.Response, err error)
Delete delete Attestation Service. Parameters: resourceGroupName - the name of the resource group. The name is case insensitive. providerName - name of the attestation service
func (ProvidersClient) DeletePreparer ¶
func (client ProvidersClient) DeletePreparer(ctx context.Context, resourceGroupName string, providerName string) (*http.Request, error)
DeletePreparer prepares the Delete request.
func (ProvidersClient) DeleteResponder ¶
func (client ProvidersClient) DeleteResponder(resp *http.Response) (result autorest.Response, err error)
DeleteResponder handles the response to the Delete request. The method always closes the http.Response Body.
func (ProvidersClient) DeleteSender ¶
DeleteSender sends the Delete request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) Get ¶
func (client ProvidersClient) Get(ctx context.Context, resourceGroupName string, providerName string) (result Provider, err error)
Get get the status of Attestation Provider. Parameters: resourceGroupName - the name of the resource group. The name is case insensitive. providerName - name of the attestation service instance
func (ProvidersClient) GetDefaultByLocation ¶
func (client ProvidersClient) GetDefaultByLocation(ctx context.Context, location string) (result Provider, err error)
GetDefaultByLocation get the default provider by location. Parameters: location - the location of the default provider.
func (ProvidersClient) GetDefaultByLocationPreparer ¶
func (client ProvidersClient) GetDefaultByLocationPreparer(ctx context.Context, location string) (*http.Request, error)
GetDefaultByLocationPreparer prepares the GetDefaultByLocation request.
func (ProvidersClient) GetDefaultByLocationResponder ¶
func (client ProvidersClient) GetDefaultByLocationResponder(resp *http.Response) (result Provider, err error)
GetDefaultByLocationResponder handles the response to the GetDefaultByLocation request. The method always closes the http.Response Body.
func (ProvidersClient) GetDefaultByLocationSender ¶
GetDefaultByLocationSender sends the GetDefaultByLocation request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) GetPreparer ¶
func (client ProvidersClient) GetPreparer(ctx context.Context, resourceGroupName string, providerName string) (*http.Request, error)
GetPreparer prepares the Get request.
func (ProvidersClient) GetResponder ¶
func (client ProvidersClient) GetResponder(resp *http.Response) (result Provider, err error)
GetResponder handles the response to the Get request. The method always closes the http.Response Body.
func (ProvidersClient) GetSender ¶
GetSender sends the Get request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) List ¶
func (client ProvidersClient) List(ctx context.Context) (result ProviderListResult, err error)
List returns a list of attestation providers in a subscription.
func (ProvidersClient) ListByResourceGroup ¶
func (client ProvidersClient) ListByResourceGroup(ctx context.Context, resourceGroupName string) (result ProviderListResult, err error)
ListByResourceGroup returns attestation providers list in a resource group. Parameters: resourceGroupName - the name of the resource group. The name is case insensitive.
func (ProvidersClient) ListByResourceGroupPreparer ¶
func (client ProvidersClient) ListByResourceGroupPreparer(ctx context.Context, resourceGroupName string) (*http.Request, error)
ListByResourceGroupPreparer prepares the ListByResourceGroup request.
func (ProvidersClient) ListByResourceGroupResponder ¶
func (client ProvidersClient) ListByResourceGroupResponder(resp *http.Response) (result ProviderListResult, err error)
ListByResourceGroupResponder handles the response to the ListByResourceGroup request. The method always closes the http.Response Body.
func (ProvidersClient) ListByResourceGroupSender ¶
ListByResourceGroupSender sends the ListByResourceGroup request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) ListDefault ¶
func (client ProvidersClient) ListDefault(ctx context.Context) (result ProviderListResult, err error)
ListDefault get the default provider
func (ProvidersClient) ListDefaultPreparer ¶
ListDefaultPreparer prepares the ListDefault request.
func (ProvidersClient) ListDefaultResponder ¶
func (client ProvidersClient) ListDefaultResponder(resp *http.Response) (result ProviderListResult, err error)
ListDefaultResponder handles the response to the ListDefault request. The method always closes the http.Response Body.
func (ProvidersClient) ListDefaultSender ¶
ListDefaultSender sends the ListDefault request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) ListPreparer ¶
ListPreparer prepares the List request.
func (ProvidersClient) ListResponder ¶
func (client ProvidersClient) ListResponder(resp *http.Response) (result ProviderListResult, err error)
ListResponder handles the response to the List request. The method always closes the http.Response Body.
func (ProvidersClient) ListSender ¶
ListSender sends the List request. The method will close the http.Response Body if it receives an error.
func (ProvidersClient) Update ¶
func (client ProvidersClient) Update(ctx context.Context, resourceGroupName string, providerName string, updateParams ServicePatchParams) (result Provider, err error)
Update updates the Attestation Provider. Parameters: resourceGroupName - the name of the resource group. The name is case insensitive. providerName - name of the attestation service instance. updateParams - client supplied parameters.
func (ProvidersClient) UpdatePreparer ¶
func (client ProvidersClient) UpdatePreparer(ctx context.Context, resourceGroupName string, providerName string, updateParams ServicePatchParams) (*http.Request, error)
UpdatePreparer prepares the Update request.
func (ProvidersClient) UpdateResponder ¶
func (client ProvidersClient) UpdateResponder(resp *http.Response) (result Provider, err error)
UpdateResponder handles the response to the Update request. The method always closes the http.Response Body.
func (ProvidersClient) UpdateSender ¶
UpdateSender sends the Update request. The method will close the http.Response Body if it receives an error.
type ProxyResource ¶
type ProxyResource struct {
// ID - READ-ONLY; Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
ID *string `json:"id,omitempty"`
// Name - READ-ONLY; The name of the resource
Name *string `json:"name,omitempty"`
// Type - READ-ONLY; The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
ProxyResource the resource model definition for a Azure Resource Manager proxy resource. It will not have tags and a location
func (ProxyResource) MarshalJSON ¶
func (pr ProxyResource) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for ProxyResource.
type Resource ¶
type Resource struct {
// ID - READ-ONLY; Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
ID *string `json:"id,omitempty"`
// Name - READ-ONLY; The name of the resource
Name *string `json:"name,omitempty"`
// Type - READ-ONLY; The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
Resource common fields that are returned in the response for all Azure Resource Manager resources
func (Resource) MarshalJSON ¶
MarshalJSON is the custom marshaler for Resource.
type ServiceCreationParams ¶
type ServiceCreationParams struct {
// Location - The supported Azure location where the attestation service instance should be created.
Location *string `json:"location,omitempty"`
// Tags - The tags that will be assigned to the attestation service instance.
Tags map[string]*string `json:"tags"`
// Properties - Properties of the attestation service instance
Properties *ServiceCreationSpecificParams `json:"properties,omitempty"`
}
ServiceCreationParams parameters for creating an attestation service instance
func (ServiceCreationParams) MarshalJSON ¶
func (scp ServiceCreationParams) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for ServiceCreationParams.
type ServiceCreationSpecificParams ¶
type ServiceCreationSpecificParams struct {
// PolicySigningCertificates - JSON Web Key Set defining a set of X.509 Certificates that will represent the parent certificate for the signing certificate used for policy operations
PolicySigningCertificates *JSONWebKeySet `json:"policySigningCertificates,omitempty"`
}
ServiceCreationSpecificParams client supplied parameters used to create a new attestation service instance.
type ServicePatchParams ¶
type ServicePatchParams struct {
// Tags - The tags that will be assigned to the attestation service instance.
Tags map[string]*string `json:"tags"`
}
ServicePatchParams parameters for patching an attestation service instance
func (ServicePatchParams) MarshalJSON ¶
func (spp ServicePatchParams) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for ServicePatchParams.
type ServiceStatus ¶
type ServiceStatus string
ServiceStatus enumerates the values for service status.
const ( // Error ... Error ServiceStatus = "Error" // NotReady ... NotReady ServiceStatus = "NotReady" // Ready ... Ready ServiceStatus = "Ready" )
func PossibleServiceStatusValues ¶
func PossibleServiceStatusValues() []ServiceStatus
PossibleServiceStatusValues returns an array of possible values for the ServiceStatus const type.
type StatusResult ¶
type StatusResult struct {
// TrustModel - Trust model for the attestation service instance.
TrustModel *string `json:"trustModel,omitempty"`
// Status - Status of attestation service. Possible values include: 'Ready', 'NotReady', 'Error'
Status ServiceStatus `json:"status,omitempty"`
// AttestURI - Gets the uri of attestation service
AttestURI *string `json:"attestUri,omitempty"`
}
StatusResult status of attestation service.
type SystemData ¶
type SystemData struct {
// CreatedBy - The identity that created the resource.
CreatedBy *string `json:"createdBy,omitempty"`
// CreatedByType - The type of identity that created the resource. Possible values include: 'User', 'Application', 'ManagedIdentity', 'Key'
CreatedByType CreatedByType `json:"createdByType,omitempty"`
// CreatedAt - The timestamp of resource creation (UTC).
CreatedAt *date.Time `json:"createdAt,omitempty"`
// LastModifiedBy - The identity that last modified the resource.
LastModifiedBy *string `json:"lastModifiedBy,omitempty"`
// LastModifiedByType - The type of identity that last modified the resource. Possible values include: 'User', 'Application', 'ManagedIdentity', 'Key'
LastModifiedByType CreatedByType `json:"lastModifiedByType,omitempty"`
// LastModifiedAt - The type of identity that last modified the resource.
LastModifiedAt *date.Time `json:"lastModifiedAt,omitempty"`
}
SystemData metadata pertaining to creation and last modification of the resource.
type TrackedResource ¶
type TrackedResource struct {
// Tags - Resource tags.
Tags map[string]*string `json:"tags"`
// Location - The geo-location where the resource lives
Location *string `json:"location,omitempty"`
// ID - READ-ONLY; Fully qualified resource ID for the resource. Ex - /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/{resourceProviderNamespace}/{resourceType}/{resourceName}
ID *string `json:"id,omitempty"`
// Name - READ-ONLY; The name of the resource
Name *string `json:"name,omitempty"`
// Type - READ-ONLY; The type of the resource. E.g. "Microsoft.Compute/virtualMachines" or "Microsoft.Storage/storageAccounts"
Type *string `json:"type,omitempty"`
}
TrackedResource the resource model definition for an Azure Resource Manager tracked top level resource which has 'tags' and a 'location'
func (TrackedResource) MarshalJSON ¶
func (tr TrackedResource) MarshalJSON() ([]byte, error)
MarshalJSON is the custom marshaler for TrackedResource.